# astroQTpy

`astroQTpy` (astronomy quadtrees in python) is designed to efficiently explore a 2D parameter space by adaptively increasing grid resolution near gradients.



<a href="https://zenodo.org/badge/latestdoi/666798611">
    <img src="https://zenodo.org/badge/666798611.svg" alt="DOI">
</a>

<a href='https://astroqtpy.readthedocs.io/en/latest/?badge=latest' >
    <img src='https://readthedocs.org/projects/astroqtpy/badge/?version=latest' alt='Documentation Status' />
</a>
